The Robomimic mixed human datasets were collected by several mixed-ability
operators using the [RoboTurk](https://roboturk.stanford.edu/) platform.
Each dataset consists of 200 demonstrations.

Each task has two versions: one with low dimensional observations (`low_dim`),
and one with images (`image`).

The datasets follow the [RLDS format](https://github.com/google-research/rlds)
to represent steps and episodes.
